import React from 'react';
import Event from './Event';
import { joinClassNames } from './classNames';

export function TextAtom({ text }:{text:string}) {
  return (
    <div className="text-atom">
      {text}
    </div>
  );
}

interface TextEventProps {
  children?: React.ReactNode;
  date: string; 
  text: string; 
  marker?: React.ReactNode; 
  id?: string; 
  card?: Function; 
}
/**
 * Use `TextEvent` to render text (including markdown) as an event.
 */
export const TextEvent = ({ children, date, text, marker, card}: TextEventProps) => {
  return (
    <Event
      date={date}
      marker={marker}
      card={card}
        
      className={joinClassNames({classNames: ['text-event']})}
      text={text}
      layout='default'
    >
      <TextAtom text={text} />
      {children}
    </Event>
  );
}



export default TextEvent; 